from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Type

import System
import System.Collections
import System.Configuration
import System.Data
import System.Globalization
import System.IO
import System.Reflection
import System.Runtime
import System.Runtime.CompilerServices
import System.Runtime.InteropServices
import System.Runtime.Remoting
import System.Runtime.Serialization
import System.Security
import System.Security.AccessControl
import System.Security.Cryptography
import System.Security.Cryptography.X509Certificates
import System.Security.Policy
import System.Threading
import System.Threading.Tasks
import System.Xml
import System.Xml.Schema
import System.Xml.Serialization
from System.ComponentModel import MarshalByValueComponent


class AssemblyHashAlgorithm:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MD5(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def SHA1(self, *args, **kwargs) -> Any: ...

    def SHA256(self, *args, **kwargs) -> Any: ...

    def SHA384(self, *args, **kwargs) -> Any: ...

    def SHA512(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class AssemblyVersionCompatibility:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def SameDomain(self, *args, **kwargs) -> Any: ...

    def SameMachine(self, *args, **kwargs) -> Any: ...

    def SameProcess(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...



from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Type

import System
import System.Collections
import System.Configuration
import System.Configuration.Assemblies
import System.Data
import System.Globalization
import System.IO
import System.Reflection
import System.Runtime
import System.Runtime.CompilerServices
import System.Runtime.InteropServices
import System.Runtime.Remoting
import System.Runtime.Serialization
import System.Security
import System.Security.AccessControl
import System.Security.Cryptography
import System.Security.Cryptography.X509Certificates
import System.Security.Policy
import System.Threading
import System.Threading.Tasks
import System.Xml
import System.Xml.Schema
import System.Xml.Serialization


class ITypeDescriptorContext:

    @property
    def Container(self): ...

    @Container.setter
    def Container(self): ...

    def GetService(self, _: Type) -> object: ...

    @property
    def Instance(self): ...

    @Instance.setter
    def Instance(self): ...

    def OnComponentChanged(self) -> None: ...

    def OnComponentChanging(self) -> bool: ...

    @property
    def PropertyDescriptor(self): ...

    @PropertyDescriptor.setter
    def PropertyDescriptor(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Container(self) -> IContainer: ...

    def get_Instance(self) -> object: ...

    def get_PropertyDescriptor(self) -> PropertyDescriptor: ...


class PropertyDescriptor:

    def AddValueChanged(self, _: object, __: Any) -> None: ...

    @property
    def AttributeArray(self): ...

    @AttributeArray.setter
    def AttributeArray(self): ...

    @property
    def Attributes(self): ...

    @Attributes.setter
    def Attributes(self): ...

    def CanResetValue(self, _: object) -> bool: ...

    @property
    def Category(self): ...

    @Category.setter
    def Category(self): ...

    @property
    def ComponentType(self): ...

    @ComponentType.setter
    def ComponentType(self): ...

    @property
    def Converter(self): ...

    @Converter.setter
    def Converter(self): ...

    def CreateAttributeCollection(self) -> AttributeCollection: ...

    def CreateInstance(self, _: Type) -> object: ...

    @property
    def Description(self): ...

    @Description.setter
    def Description(self): ...

    @property
    def DesignTimeOnly(self): ...

    @DesignTimeOnly.setter
    def DesignTimeOnly(self): ...

    @property
    def DisplayName(self): ...

    @DisplayName.setter
    def DisplayName(self): ...

    def Equals(self, _: object) -> bool: ...

    def FillAttributes(self, _: List) -> None: ...

    def Finalize(self) -> None: ...

    def FindMethod(self,
            _: Type,
            __: str,
            ___: List[Type],
            ____: Type,
            _____: bool,
            ) -> System.Reflection.MethodInfo: ...

    def GetChildProperties(self,
            _: object,
            __: List[System.Attribute],
            ) -> PropertyDescriptorCollection: ...

    def GetEditor(self, _: Type) -> object: ...

    def GetHashCode(self) -> int: ...

    def GetInvocationTarget(self, _: Type, __: object) -> object: ...

    def GetInvokee(self, _: Type, __: object) -> object: ...

    def GetSite(self, _: object) -> ISite: ...

    def GetType(self) -> Type: ...

    def GetTypeFromName(self, _: str) -> Type: ...

    def GetValue(self, _: object) -> object: ...

    def GetValueChangedHandler(self, _: object) -> Any: ...

    @property
    def IsBrowsable(self): ...

    @IsBrowsable.setter
    def IsBrowsable(self): ...

    @property
    def IsLocalizable(self): ...

    @IsLocalizable.setter
    def IsLocalizable(self): ...

    @property
    def IsReadOnly(self): ...

    @IsReadOnly.setter
    def IsReadOnly(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    @property
    def NameHashCode(self): ...

    @NameHashCode.setter
    def NameHashCode(self): ...

    def OnValueChanged(self, _: object, __: System.EventArgs) -> None: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def PropertyType(self): ...

    @PropertyType.setter
    def PropertyType(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def RemoveValueChanged(self, _: object, __: Any) -> None: ...

    def ResetValue(self, _: object) -> None: ...

    @property
    def SerializationVisibility(self): ...

    @SerializationVisibility.setter
    def SerializationVisibility(self): ...

    def SetValue(self, _: object, __: object) -> None: ...

    def ShouldSerializeValue(self, _: object) -> bool: ...

    @property
    def SupportsChangeEvents(self): ...

    @SupportsChangeEvents.setter
    def SupportsChangeEvents(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_AttributeArray(self) -> List[System.Attribute]: ...

    def get_Attributes(self) -> AttributeCollection: ...

    def get_Category(self) -> str: ...

    def get_ComponentType(self) -> Type: ...

    def get_Converter(self) -> TypeConverter: ...

    def get_Description(self) -> str: ...

    def get_DesignTimeOnly(self) -> bool: ...

    def get_DisplayName(self) -> str: ...

    def get_IsBrowsable(self) -> bool: ...

    def get_IsLocalizable(self) -> bool: ...

    def get_IsReadOnly(self) -> bool: ...

    def get_Name(self) -> str: ...

    def get_NameHashCode(self) -> int: ...

    def get_PropertyType(self) -> Type: ...

    def get_SerializationVisibility(self) -> DesignerSerializationVisibility: ...

    def get_SupportsChangeEvents(self) -> bool: ...

    def set_AttributeArray(self, _: List[System.Attribute]) -> None: ...


class AttributeCollection:

    @property
    def Attributes(self): ...

    @Attributes.setter
    def Attributes(self): ...

    def Contains(self, _: System.Attribute) -> bool: ...

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def FromExisting(self,
            _: AttributeCollection,
            __: List[System.Attribute],
            ) -> AttributeCollection: ...

    def GetDefaultAttribute(self, _: Type) -> System.Attribute: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def Matches(self, _: System.Attribute) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Attributes(self) -> List[System.Attribute]: ...

    def get_Count(self) -> int: ...

    def get_Item(self, _: int) -> System.Attribute: ...


class PropertyDescriptorCollection:

    def Add(self, _: PropertyDescriptor) -> int: ...

    def Clear(self) -> None: ...

    def Contains(self, _: PropertyDescriptor) -> bool: ...

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Find(self, _: str, __: bool) -> PropertyDescriptor: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def IndexOf(self, _: PropertyDescriptor) -> int: ...

    def Insert(self, _: int, __: PropertyDescriptor) -> None: ...

    def InternalSort(self, _: List[str]) -> None: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: PropertyDescriptor) -> None: ...

    def RemoveAt(self, _: int) -> None: ...

    def Sort(self,
            _: List[str],
            __: System.Collections.IComparer,
            ) -> PropertyDescriptorCollection: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Count(self) -> int: ...

    def get_Item(self, _: str) -> PropertyDescriptor: ...


class TypeConverter:

    def CanConvertFrom(self,
            _: ITypeDescriptorContext,
            __: Type,
            ) -> bool: ...

    def CanConvertTo(self,
            _: ITypeDescriptorContext,
            __: Type,
            ) -> bool: ...

    def ConvertFrom(self,
            _: ITypeDescriptorContext,
            __: System.Globalization.CultureInfo,
            ___: object,
            ) -> object: ...

    def ConvertFromInvariantString(self,
            _: ITypeDescriptorContext,
            __: str,
            ) -> object: ...

    def ConvertFromString(self,
            _: ITypeDescriptorContext,
            __: System.Globalization.CultureInfo,
            ___: str,
            ) -> object: ...

    def ConvertTo(self,
            _: ITypeDescriptorContext,
            __: System.Globalization.CultureInfo,
            ___: object,
            ____: Type,
            ) -> object: ...

    def ConvertToInvariantString(self,
            _: ITypeDescriptorContext,
            __: object,
            ) -> str: ...

    def ConvertToString(self,
            _: ITypeDescriptorContext,
            __: System.Globalization.CultureInfo,
            ___: object,
            ) -> str: ...

    def CreateInstance(self,
            _: ITypeDescriptorContext,
            __: System.Collections.IDictionary,
            ) -> object: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetConvertFromException(self, _: object) -> Exception: ...

    def GetConvertToException(self, _: object, __: Type) -> Exception: ...

    def GetCreateInstanceSupported(self,
            _: ITypeDescriptorContext,
            ) -> bool: ...

    def GetHashCode(self) -> int: ...

    def GetProperties(self,
            _: ITypeDescriptorContext,
            __: object,
            ___: List[System.Attribute],
            ) -> PropertyDescriptorCollection: ...

    def GetPropertiesSupported(self,
            _: ITypeDescriptorContext,
            ) -> bool: ...

    def GetStandardValues(self,
            _: ITypeDescriptorContext,
            ) -> Any: ...

    def GetStandardValuesExclusive(self,
            _: ITypeDescriptorContext,
            ) -> bool: ...

    def GetStandardValuesSupported(self,
            _: ITypeDescriptorContext,
            ) -> bool: ...

    def GetType(self) -> Type: ...

    def IsValid(self,
            _: ITypeDescriptorContext,
            __: object,
            ) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def SimplePropertyDescriptor(self, *args, **kwargs) -> Any: ...

    def SortProperties(self,
            _: PropertyDescriptorCollection,
            __: List[str],
            ) -> PropertyDescriptorCollection: ...

    def StandardValuesCollection(self, *args, **kwargs) -> Any: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class DesignerSerializationVisibility:

    def CompareTo(self, _: object) -> int: ...

    def Content(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def Hidden(self, *args, **kwargs) -> Any: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Visible(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class MarshalByValueComponent:

    @property
    def Container(self): ...

    @Container.setter
    def Container(self): ...

    @property
    def DesignMode(self): ...

    @DesignMode.setter
    def DesignMode(self): ...

    def Dispose(self, _: bool) -> None: ...

    def Disposed(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Events(self): ...

    @Events.setter
    def Events(self): ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetService(self, _: Type) -> object: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def Site(self): ...

    @Site.setter
    def Site(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_Disposed(self, _: Any) -> None: ...

    def get_Container(self) -> IContainer: ...

    def get_DesignMode(self) -> bool: ...

    def get_Events(self) -> EventHandlerList: ...

    def get_Site(self) -> ISite: ...

    def remove_Disposed(self, _: Any) -> None: ...

    def set_Site(self, _: ISite) -> None: ...


class PropertyChangedEventArgs:

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def PropertyName(self): ...

    @PropertyName.setter
    def PropertyName(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_PropertyName(self) -> str: ...


class PropertyChangedEventHandler:

    def BeginInvoke(self,
            _: object,
            __: PropertyChangedEventArgs,
            ___: Any,
            ____: object,
            ) -> Any: ...

    def Clone(self) -> object: ...

    def Combine(self, _: Any, __: Any) -> Any: ...

    def CombineImpl(self, _: Any) -> Any: ...

    def CreateDelegate(self,
            _: Type,
            __: object,
            ___: str,
            ____: bool,
            _____: bool,
            ) -> Any: ...

    def DynamicInvoke(self, _: List[object]) -> object: ...

    def DynamicInvokeImpl(self, _: List[object]) -> object: ...

    def EndInvoke(self, _: Any) -> None: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetInvocationList(self) -> List[Any]: ...

    def GetMethodImpl(self) -> System.Reflection.MethodInfo: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    def Invoke(self,
            _: object,
            __: PropertyChangedEventArgs,
            ) -> None: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Method(self): ...

    @Method.setter
    def Method(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: Any, __: Any) -> Any: ...

    def RemoveAll(self, _: Any, __: Any) -> Any: ...

    def RemoveImpl(self, _: Any) -> Any: ...

    @property
    def Target(self): ...

    @Target.setter
    def Target(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Method(self) -> System.Reflection.MethodInfo: ...

    def get_Target(self) -> object: ...

    def op_Equality(self, _: Any, __: Any) -> bool: ...

    def op_Inequality(self, _: Any, __: Any) -> bool: ...


class CollectionChangeEventArgs:

    @property
    def Action(self): ...

    @Action.setter
    def Action(self): ...

    @property
    def Element(self): ...

    @Element.setter
    def Element(self): ...

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Action(self) -> CollectionChangeAction: ...

    def get_Element(self) -> object: ...


class CollectionChangeEventHandler:

    def BeginInvoke(self,
            _: object,
            __: CollectionChangeEventArgs,
            ___: Any,
            ____: object,
            ) -> Any: ...

    def Clone(self) -> object: ...

    def Combine(self, _: Any, __: Any) -> Any: ...

    def CombineImpl(self, _: Any) -> Any: ...

    def CreateDelegate(self,
            _: Type,
            __: object,
            ___: str,
            ____: bool,
            _____: bool,
            ) -> Any: ...

    def DynamicInvoke(self, _: List[object]) -> object: ...

    def DynamicInvokeImpl(self, _: List[object]) -> object: ...

    def EndInvoke(self, _: Any) -> None: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetInvocationList(self) -> List[Any]: ...

    def GetMethodImpl(self) -> System.Reflection.MethodInfo: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    def Invoke(self,
            _: object,
            __: CollectionChangeEventArgs,
            ) -> None: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Method(self): ...

    @Method.setter
    def Method(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: Any, __: Any) -> Any: ...

    def RemoveAll(self, _: Any, __: Any) -> Any: ...

    def RemoveImpl(self, _: Any) -> Any: ...

    @property
    def Target(self): ...

    @Target.setter
    def Target(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Method(self) -> System.Reflection.MethodInfo: ...

    def get_Target(self) -> object: ...

    def op_Equality(self, _: Any, __: Any) -> bool: ...

    def op_Inequality(self, _: Any, __: Any) -> bool: ...


class ListChangedEventArgs:

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def ListChangedType(self): ...

    @ListChangedType.setter
    def ListChangedType(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def NewIndex(self): ...

    @NewIndex.setter
    def NewIndex(self): ...

    @property
    def OldIndex(self): ...

    @OldIndex.setter
    def OldIndex(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def PropertyDescriptor(self): ...

    @PropertyDescriptor.setter
    def PropertyDescriptor(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_ListChangedType(self) -> ListChangedType: ...

    def get_NewIndex(self) -> int: ...

    def get_OldIndex(self) -> int: ...

    def get_PropertyDescriptor(self) -> PropertyDescriptor: ...


class ListChangedEventHandler:

    def BeginInvoke(self,
            _: object,
            __: ListChangedEventArgs,
            ___: Any,
            ____: object,
            ) -> Any: ...

    def Clone(self) -> object: ...

    def Combine(self, _: Any, __: Any) -> Any: ...

    def CombineImpl(self, _: Any) -> Any: ...

    def CreateDelegate(self,
            _: Type,
            __: object,
            ___: str,
            ____: bool,
            _____: bool,
            ) -> Any: ...

    def DynamicInvoke(self, _: List[object]) -> object: ...

    def DynamicInvokeImpl(self, _: List[object]) -> object: ...

    def EndInvoke(self, _: Any) -> None: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetInvocationList(self) -> List[Any]: ...

    def GetMethodImpl(self) -> System.Reflection.MethodInfo: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    def Invoke(self,
            _: object,
            __: ListChangedEventArgs,
            ) -> None: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Method(self): ...

    @Method.setter
    def Method(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: Any, __: Any) -> Any: ...

    def RemoveAll(self, _: Any, __: Any) -> Any: ...

    def RemoveImpl(self, _: Any) -> Any: ...

    @property
    def Target(self): ...

    @Target.setter
    def Target(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Method(self) -> System.Reflection.MethodInfo: ...

    def get_Target(self) -> object: ...

    def op_Equality(self, _: Any, __: Any) -> bool: ...

    def op_Inequality(self, _: Any, __: Any) -> bool: ...


class IContainer:

    def Add(self, _: IComponent, __: str) -> None: ...

    @property
    def Components(self): ...

    @Components.setter
    def Components(self): ...

    def Dispose(self) -> None: ...

    def Remove(self, _: IComponent) -> None: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Components(self) -> ComponentCollection: ...


class EventHandlerList:

    def AddHandler(self, _: object, __: Any) -> None: ...

    def AddHandlers(self, _: EventHandlerList) -> None: ...

    def Dispose(self) -> None: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def RemoveHandler(self, _: object, __: Any) -> None: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Item(self, _: object) -> Any: ...

    def set_Item(self, _: object, __: Any) -> None: ...


class ISite:

    @property
    def Component(self): ...

    @Component.setter
    def Component(self): ...

    @property
    def Container(self): ...

    @Container.setter
    def Container(self): ...

    @property
    def DesignMode(self): ...

    @DesignMode.setter
    def DesignMode(self): ...

    def GetService(self, _: Type) -> object: ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Component(self) -> IComponent: ...

    def get_Container(self) -> IContainer: ...

    def get_DesignMode(self) -> bool: ...

    def get_Name(self) -> str: ...

    def set_Name(self, _: str) -> None: ...


class CollectionChangeAction:

    def Add(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Refresh(self, *args, **kwargs) -> Any: ...

    def Remove(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class IComponent:

    def Dispose(self) -> None: ...

    def Disposed(self, *args, **kwargs) -> Any: ...

    @property
    def Site(self): ...

    @Site.setter
    def Site(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_Disposed(self, _: Any) -> None: ...

    def get_Site(self) -> ISite: ...

    def remove_Disposed(self, _: Any) -> None: ...

    def set_Site(self, _: ISite) -> None: ...


class ComponentCollection:

    def CopyTo(self, _: List[IComponent], __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def InnerList(self): ...

    @InnerList.setter
    def InnerList(self): ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Count(self) -> int: ...

    def get_InnerList(self) -> List: ...

    def get_Item(self, _: str) -> IComponent: ...


class ListChangedType:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def ItemAdded(self, *args, **kwargs) -> Any: ...

    def ItemChanged(self, *args, **kwargs) -> Any: ...

    def ItemDeleted(self, *args, **kwargs) -> Any: ...

    def ItemMoved(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def PropertyDescriptorAdded(self, *args, **kwargs) -> Any: ...

    def PropertyDescriptorChanged(self, *args, **kwargs) -> Any: ...

    def PropertyDescriptorDeleted(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Reset(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...
